from xdg.BaseDirectory import (
        load_first_config,
        save_data_path
        )
import json

def _get_config(app=None, file=None):
    return json.load(
            open(
                load_first_config(
                    'oauth2token',
                    app,
                    file),
                'r'))


def get_json_config(app=None):
    return (_get_config(app, 'config.json'),
            _get_config(app, 'scopes.json')
            )


def get_credentials_file(app=None, user=None, override=False): 
    mode = 'wb' if override else 'rb+'
    return open(save_data_path(
        'oauth2token', app) + '/' + user, mode)



#!/usr/bin/env python

from google_auth_oauthlib.flow import InstalledAppFlow
import pickle
import argparse
import os
from google.auth.transport.requests import Request
from .app_creds import get_json_config, get_credentials_file


def create_user_credentials(app=None, user=None, **kwargs): 
    flow = InstalledAppFlow.from_client_config(
            *get_json_config(app=app)
       )

    flow.run_local_server(port=0)

    creds = flow.credentials
    creds._scopes = flow.oauth2session.token["scope"]

    pickle.dump(creds, get_credentials_file(app=app, user=user, override=True))

def get_token(**kwargs):
    with get_credentials_file(**kwargs) as user_file:
        creds = pickle.load(user_file)
        if creds.expired:
            creds.refresh(Request())
            user_file.seek(0)
            pickle.dump(creds, user_file)
            user_file.truncate()
    return creds.token



import setuptools

with open("README.rst", "r") as fh:
    long_description = fh.read()

setuptools.setup(
    name="oauth2token",
    version="0.0.3",
    author="VannTen",
    author_email="mg@max.gautier.name",
    description="Oauth2 token management for cli applications",
    long_description=long_description,
    long_description_content_type="text/x-rst",
    url="https://github.com/VannTen/oauth2token",
    packages=setuptools.find_packages(where='.'),
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: GNU General Public License v3 (GPLv3)",
        "Operating System :: POSIX :: Linux",
        "Intended Audience :: End Users/Desktop",
        "Development Status :: 2 - Pre-Alpha"
    ],
    scripts = [
        'bin/oauth2create',
        'bin/oauth2get'
    ],
    python_requires='>=3.6',
    install_requires=[
        'google_auth_oauthlib',
        'pyxdg'
    ]
)
